//
//  TableViewControllerRegistroSalud.swift
//  MyKennel
//
//  Created by Juan Antonio Sánchez Carrillo on 20/6/15.
//  Copyright (c) 2015 Juan Antonio Sánchez Carrillo. All rights reserved.
//

import UIKit
import CoreData

class TableViewControllerRegistroSalud: UITableViewController {

    //Declaro Array para almacenar los datos de la tabla
    var datosConsultaSalud : Array<AnyObject> = []
    
    //Declaro Constante que almacena el alto de la celda
    let alturaCelda: CGFloat = 80.0
    
    //Función para presentar datos en la vista de tabla cuando esta se cargue
    override func viewDidAppear(animated: Bool) {
        super.viewDidAppear(true)
        
    //Declaro constante de la case AppDelegate
    let appdel : AppDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        
    //Declaro Constante del Managed Object Context
    let managedObjectContexto : NSManagedObjectContext = appdel.managedObjectContext!
        
    //Declaro Constante de la clase NSFetchrequest para la consulta de datos.
    let frequest = NSFetchRequest(entityName: "Salud")
        
    //Cargo el Array y hago la consulta
    datosConsultaSalud = managedObjectContexto.executeFetchRequest(frequest,error : nil)!
        
    //Vuelvo a cargar la Tabla
    tableView.reloadData()
    
    }
    
    //MARK: - Métodos Propios
    
    //Método que hace que se presenten en los textField los datos al pasar a la vista de detalle
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject!) {
        //Condicional para ver si el identificador es el mismo
        if segue.identifier == "actualizaSalud" {
            //Variable para almacenar el índice de la tabla
            var indexPath : NSIndexPath = self.tableView.indexPathForSelectedRow()!
            //Creo Objeto para la clase NSManagedObject y le paso el array y la fila seleccionada
            var selectedItem : NSManagedObject = datosConsultaSalud[indexPath.row] as! NSManagedObject
            //Presento la vista de Detalle
            let vistaDetalleSalud : ViewControllerDetalleSalud = segue.destinationViewController as! ViewControllerDetalleSalud
            //Paso el valor seleccionado en la propiedad SelectItem
            vistaDetalleSalud.nombrePrueba = selectedItem.valueForKey("prueba") as? String
            vistaDetalleSalud.resultadoPrueba = selectedItem.valueForKey("resultado") as? String
            vistaDetalleSalud.fechaPrueba = selectedItem.valueForKey("fecha") as? String
            vistaDetalleSalud.existePrueba = selectedItem
        }
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Uncomment the following line to preserve selection between presentations
        // self.clearsSelectionOnViewWillAppear = false

        // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
        // self.navigationItem.rightBarButtonItem = self.editButtonItem()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        // #warning Potentially incomplete method implementation.
        // Return the number of sections.
        return 1
    }

    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        // #warning Incomplete method implementation.
        // Return the number of rows in the section.
        return datosConsultaSalud.count
    }

    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        
        //Identificador de Celda
        let CellID: NSString = "Cell"
        
        //Paso Identificador de celda
        var cell: UITableViewCell = tableView.dequeueReusableCellWithIdentifier(CellID as String) as! UITableViewCell
        
        //Creo objeto NSManagedObject
        var datos: NSManagedObject = datosConsultaSalud[indexPath.row] as! NSManagedObject
        
        //String que almacena Nombre de la Prueba
        var nombre = datos.valueForKeyPath("prueba") as! String
        
        //String que almacena el Resultado de la Prueba
        var resultado = datos.valueForKeyPath("resultado") as! String
        
        //Guardo prueba + resultado
        var nombreApellidos = nombre.stringByAppendingString(" \(resultado)")
        
        //Creo Constante para establecer un tipo de fuente y su tamaño
        let font: UIFont = UIFont (name: "AvenirNext-Regular",size:16.0)!
        
        //Creo Constante para establecer altura de celda
        let alturaCeldaX: CGFloat = alturaCelda - 15
        
        //Creo Constante a la clase Objective-C (Pod)
        let placeHolder = BMInitialsPlaceholderView(diameter: alturaCeldaX)
        
        //Modificamos las propiedades del placeHolder
        placeHolder.circleColor = circleColorForIndexPath (indexPath)
        
        placeHolder.initials = initialsStringForPersonasString (nombreApellidos) as String
        
        //Le Paso al circulo el tipo de fuente
        placeHolder.font = font
        
        //Paso el PlaceHolder como accesoryView de mi celda
        cell.accessoryView = placeHolder
        
        //Paso la fuente y el tamaño a las celdas
        cell.textLabel?.font = font
        
        
        //Presento la información Nombre - Afijo en Pantalla con la imagen del perro
        cell.textLabel?.text = "\(nombre) , \(resultado)"
        
        cell.detailTextLabel?.text = datos.valueForKeyPath("fecha") as? String
        
        return cell
    }
    
    //Funcion que devuelve un color aleatorio para el circulo
    func circleColorForIndexPath (indexPath: NSIndexPath) -> UIColor
    {
        //Creo 3 Variables para almacenar tres valores aleatorios
        var randomRed: CGFloat = CGFloat(drand48())
        var randomGreen: CGFloat = CGFloat(drand48())
        var randomBlue: CGFloat = CGFloat(drand48())
        
        return UIColor(red: randomRed, green: randomGreen,blue: randomBlue, alpha:1.0)
    }
    
    func initialsStringForPersonasString (perrosString: NSString) -> NSString{
        
        let composicion = perrosString.componentsSeparatedByString(" ")
        
        if (composicion.count >= 2 ){
            let firstName: NSString = composicion[0] as! NSString
            let lastName: NSString = composicion[1] as! NSString
            
            return String(format: "\(firstName.substringToIndex(1))\(lastName.substringToIndex(1))",locale:nil)
        }
        return "Desconocido"
    }
    
    //Permite eliminar registros de mi tabla, actualizando mi modelo de datos
    override func tableView(tableView: UITableView?, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        
        let appdel: AppDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        
        let managedObjectContexto : NSManagedObjectContext = appdel.managedObjectContext!
        
        if editingStyle == UITableViewCellEditingStyle.Delete{
            
            if let tableV = tableView{
                
                managedObjectContexto.deleteObject(datosConsultaSalud[indexPath.row] as! NSManagedObject)
                
                datosConsultaSalud.removeAtIndex(indexPath.row)
                
                tableV.deleteRowsAtIndexPaths([indexPath], withRowAnimation: UITableViewRowAnimation.Fade)
            }
            
            var error: NSError? = nil
            
            if !managedObjectContexto.save(&error){
                
                abort ()
                
            }
            
        }
        
        
    }


}
